==> kubernetes-model-batch-6.6.2-sources.jar: io/fabric8/kubernetes/api/model/batch/v1/UncountedTerminatedPodsFluentImpl.java <==
package io.fabric8.kubernetes.api.model.batch.v1;

import java.lang.SuppressWarnings;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class UncountedTerminatedPodsFluentImpl<A extends UncountedTerminatedPodsFluent<A>> extends BaseFluent<A> implements UncountedTerminatedPodsFluent<A>{
  public UncountedTerminatedPodsFluentImpl() {
  }
  public UncountedTerminatedPodsFluentImpl(UncountedTerminatedPods instance) {
    this.withFailed(instance.getFailed()); 
    this.withSucceeded(instance.getSucceeded()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private List<String> failed = new ArrayList<String>();
  private List<String> succeeded = new ArrayList<String>();
  private Map<String,Object> additionalProperties;
  public A addToFailed(Integer index,String item) {
    if (this.failed == null) {this.failed = new ArrayList<String>();}
    this.failed.add(index, item);
    return (A)this;
  }
  public A setToFailed(Integer index,String item) {
    if (this.failed == null) {this.failed = new ArrayList<String>();}
    this.failed.set(index, item); return (A)this;
  }
  public A addToFailed(java.lang.String... items) {
    if (this.failed == null) {this.failed = new ArrayList<String>();}
    for (String item : items) {this.failed.add(item);} return (A)this;
  }
  public A addAllToFailed(Collection<String> items) {
    if (this.failed == null) {this.failed = new ArrayList<String>();}
    for (String item : items) {this.failed.add(item);} return (A)this;
  }
  public A removeFromFailed(java.lang.String... items) {
    for (String item : items) {if (this.failed!= null){ this.failed.remove(item);}} return (A)this;
  }
  public A removeAllFromFailed(Collection<String> items) {
    for (String item : items) {if (this.failed!= null){ this.failed.remove(item);}} return (A)this;
  }
  public List<String> getFailed() {
    return this.failed;
  }
  public String getFailed(Integer index) {
    return this.failed.get(index);
  }
  public String getFirstFailed() {
    return this.failed.get(0);
  }
  public String getLastFailed() {
    return this.failed.get(failed.size() - 1);
  }
  public String getMatchingFailed(Predicate<String> predicate) {
    for (String item: failed) { if(predicate.test(item)){ return item;} } return null;
  }
  public Boolean hasMatchingFailed(Predicate<String> predicate) {
    for (String item: failed) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withFailed(List<String> failed) {
    if (failed != null) {this.failed = new ArrayList(); for (String item : failed){this.addToFailed(item);}} else { this.failed = null;} return (A) this;
  }
  public A withFailed(java.lang.String... failed) {
    if (this.failed != null) {this.failed.clear();}
    if (failed != null) {for (String item :failed){ this.addToFailed(item);}} return (A) this;
  }
  public Boolean hasFailed() {
    return failed != null && !failed.isEmpty();
  }
  public A addToSucceeded(Integer index,String item) {
    if (this.succeeded == null) {this.succeeded = new ArrayList<String>();}
    this.succeeded.add(index, item);
    return (A)this;
  }
  public A setToSucceeded(Integer index,String item) {
    if (this.succeeded == null) {this.succeeded = new ArrayList<String>();}
    this.succeeded.set(index, item); return (A)this;
  }
  public A addToSucceeded(java.lang.String... items) {
    if (this.succeeded == null) {this.succeeded = new ArrayList<String>();}
    for (String item : items) {this.succeeded.add(item);} return (A)this;
  }
  public A addAllToSucceeded(Collection<String> items) {
    if (this.succeeded == null) {this.succeeded = new ArrayList<String>();}
    for (String item : items) {this.succeeded.add(item);} return (A)this;
  }
  public A removeFromSucceeded(java.lang.String... items) {
    for (String item : items) {if (this.succeeded!= null){ this.succeeded.remove(item);}} return (A)this;
  }
  public A removeAllFromSucceeded(Collection<String> items) {
    for (String item : items) {if (this.succeeded!= null){ this.succeeded.remove(item);}} return (A)this;
  }
  public List<String> getSucceeded() {
    return this.succeeded;
  }
  public String getSucceeded(Integer index) {
    return this.succeeded.get(index);
  }
  public String getFirstSucceeded() {
    return this.succeeded.get(0);
  }
  public String getLastSucceeded() {
    return this.succeeded.get(succeeded.size() - 1);
  }
  public String getMatchingSucceeded(Predicate<String> predicate) {
    for (String item: succeeded) { if(predicate.test(item)){ return item;} } return null;
  }
  public Boolean hasMatchingSucceeded(Predicate<String> predicate) {
    for (String item: succeeded) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withSucceeded(List<String> succeeded) {
    if (succeeded != null) {this.succeeded = new ArrayList(); for (String item : succeeded){this.addToSucceeded(item);}} else { this.succeeded = null;} return (A) this;
  }
  public A withSucceeded(java.lang.String... succeeded) {
    if (this.succeeded != null) {this.succeeded.clear();}
    if (succeeded != null) {for (String item :succeeded){ this.addToSucceeded(item);}} return (A) this;
  }
  public Boolean hasSucceeded() {
    return succeeded != null && !succeeded.isEmpty();
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    UncountedTerminatedPodsFluentImpl that = (UncountedTerminatedPodsFluentImpl) o;
    if (failed != null ? !failed.equals(that.failed) :that.failed != null) return false;
    if (succeeded != null ? !succeeded.equals(that.succeeded) :that.succeeded != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(failed,  succeeded,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (failed != null && !failed.isEmpty()) { sb.append("failed:"); sb.append(failed + ","); }
    if (succeeded != null && !succeeded.isEmpty()) { sb.append("succeeded:"); sb.append(succeeded + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  
}

==> kubernetes-model-batch-6.7.2-sources.jar: io/fabric8/kubernetes/api/model/batch/v1/UncountedTerminatedPodsFluentImpl.java <==
package io.fabric8.kubernetes.api.model.batch.v1;

import java.lang.SuppressWarnings;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class UncountedTerminatedPodsFluentImpl<A extends UncountedTerminatedPodsFluent<A>> extends BaseFluent<A> implements UncountedTerminatedPodsFluent<A>{
  public UncountedTerminatedPodsFluentImpl() {
  }
  public UncountedTerminatedPodsFluentImpl(UncountedTerminatedPods instance) {
    if (instance != null) {
      this.withFailed(instance.getFailed());
      this.withSucceeded(instance.getSucceeded());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
  }
  private List<String> failed = new ArrayList<String>();
  private List<String> succeeded = new ArrayList<String>();
  private Map<String,Object> additionalProperties;
  public A addToFailed(int index,String item) {
    if (this.failed == null) {this.failed = new ArrayList<String>();}
    this.failed.add(index, item);
    return (A)this;
  }
  public A setToFailed(int index,String item) {
    if (this.failed == null) {this.failed = new ArrayList<String>();}
    this.failed.set(index, item); return (A)this;
  }
  public A addToFailed(java.lang.String... items) {
    if (this.failed == null) {this.failed = new ArrayList<String>();}
    for (String item : items) {this.failed.add(item);} return (A)this;
  }
  public A addAllToFailed(Collection<String> items) {
    if (this.failed == null) {this.failed = new ArrayList<String>();}
    for (String item : items) {this.failed.add(item);} return (A)this;
  }
  public A removeFromFailed(java.lang.String... items) {
    for (String item : items) {if (this.failed!= null){ this.failed.remove(item);}} return (A)this;
  }
  public A removeAllFromFailed(Collection<String> items) {
    for (String item : items) {if (this.failed!= null){ this.failed.remove(item);}} return (A)this;
  }
  public List<String> getFailed() {
    return this.failed;
  }
  public String getFailed(int index) {
    return this.failed.get(index);
  }
  public String getFirstFailed() {
    return this.failed.get(0);
  }
  public String getLastFailed() {
    return this.failed.get(failed.size() - 1);
  }
  public String getMatchingFailed(Predicate<String> predicate) {
    for (String item: failed) { if(predicate.test(item)){ return item;} } return null;
  }
  public Boolean hasMatchingFailed(Predicate<String> predicate) {
    for (String item: failed) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withFailed(List<String> failed) {
    if (failed != null) {this.failed = new ArrayList(); for (String item : failed){this.addToFailed(item);}} else { this.failed = null;} return (A) this;
  }
  public A withFailed(java.lang.String... failed) {
    if (this.failed != null) {this.failed.clear(); _visitables.remove("failed"); }
    if (failed != null) {for (String item :failed){ this.addToFailed(item);}} return (A) this;
  }
  public Boolean hasFailed() {
    return failed != null && !failed.isEmpty();
  }
  public A addToSucceeded(int index,String item) {
    if (this.succeeded == null) {this.succeeded = new ArrayList<String>();}
    this.succeeded.add(index, item);
    return (A)this;
  }
  public A setToSucceeded(int index,String item) {
    if (this.succeeded == null) {this.succeeded = new ArrayList<String>();}
    this.succeeded.set(index, item); return (A)this;
  }
  public A addToSucceeded(java.lang.String... items) {
    if (this.succeeded == null) {this.succeeded = new ArrayList<String>();}
    for (String item : items) {this.succeeded.add(item);} return (A)this;
  }
  public A addAllToSucceeded(Collection<String> items) {
    if (this.succeeded == null) {this.succeeded = new ArrayList<String>();}
    for (String item : items) {this.succeeded.add(item);} return (A)this;
  }
  public A removeFromSucceeded(java.lang.String... items) {
    for (String item : items) {if (this.succeeded!= null){ this.succeeded.remove(item);}} return (A)this;
  }
  public A removeAllFromSucceeded(Collection<String> items) {
    for (String item : items) {if (this.succeeded!= null){ this.succeeded.remove(item);}} return (A)this;
  }
  public List<String> getSucceeded() {
    return this.succeeded;
  }
  public String getSucceeded(int index) {
    return this.succeeded.get(index);
  }
  public String getFirstSucceeded() {
    return this.succeeded.get(0);
  }
  public String getLastSucceeded() {
    return this.succeeded.get(succeeded.size() - 1);
  }
  public String getMatchingSucceeded(Predicate<String> predicate) {
    for (String item: succeeded) { if(predicate.test(item)){ return item;} } return null;
  }
  public Boolean hasMatchingSucceeded(Predicate<String> predicate) {
    for (String item: succeeded) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withSucceeded(List<String> succeeded) {
    if (succeeded != null) {this.succeeded = new ArrayList(); for (String item : succeeded){this.addToSucceeded(item);}} else { this.succeeded = null;} return (A) this;
  }
  public A withSucceeded(java.lang.String... succeeded) {
    if (this.succeeded != null) {this.succeeded.clear(); _visitables.remove("succeeded"); }
    if (succeeded != null) {for (String item :succeeded){ this.addToSucceeded(item);}} return (A) this;
  }
  public Boolean hasSucceeded() {
    return succeeded != null && !succeeded.isEmpty();
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    UncountedTerminatedPodsFluentImpl that = (UncountedTerminatedPodsFluentImpl) o;
    if (!java.util.Objects.equals(failed, that.failed)) return false;

    if (!java.util.Objects.equals(succeeded, that.succeeded)) return false;

    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(failed,  succeeded,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (failed != null && !failed.isEmpty()) { sb.append("failed:"); sb.append(failed + ","); }
    if (succeeded != null && !succeeded.isEmpty()) { sb.append("succeeded:"); sb.append(succeeded + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  
}
